@@ -1,6 +1,22 @@
 import numpy as np
 import pandas as pd
 
+
+#make funtion to return list of all pydataset datasets
+def lista_datasets():
+    import pydataset
+    return(pydataset.data)
+
+#make funtion to print documentation of specific dataset of pydataset
+def documentazione_dataset(nome_dataset):
+    import pydataset
+    print(pydataset.data(nome_dataset).__doc__)
+
+#make funtion to return dataframe of secific dataset of pydataset
+def importa_dataset(nome_dataset):
+    import pydataset
+    return(pydataset.data(nome_dataset))
+
 #make function to return list of columns in dataframe
 def lista_colonne(df):
     return(df.columns)
